==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'لا يوجد اي رسائل منتدى',

	// B
	'bouton_radio_articles_futurs' => ' ( منحصرأ براى مقالات آينده (بر روى  داده پى ها بى تأثير ميباشد',
	'bouton_radio_articles_tous' => 'به تمامى مقاله ها، بدون استثناء',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'به تمامى مقاله ها، بجز آنهائى كه سخنگاهشان غير فعال است. ',
	'bouton_radio_enregistrement_obligatoire' => 'ضبط اجبارى، (كاربران بايد, براى داشتن آدرس الكترونيكى  مشترك شوند تا بتوانند پيامهايشان را پست كنند)      ',
	'bouton_radio_moderation_priori' => 'تعديل از پيش (نوشته‌ها پيش از تأييد مديران منتشر نمي‌شوند).',
	'bouton_radio_modere_abonnement' => 'براى مشتركين',
	'bouton_radio_modere_posteriori' => 'تعديل بعدي ',
	'bouton_radio_modere_priori' => 'تعديل از پيش',
	'bouton_radio_publication_immediate' => 'انتشار فورى پيامها 
 (پيامها بمحض فرستاده شدن نمايان ميشوند سپس گردانند گان سايت ميتوانند آنها را حذف كنند)',

	// D
	'documents_interdits_forum' => 'سندهاي ممنوع در سخناگاه ',

	// E
	'erreur_enregistrement_message' => 'لم يتم تسجيل رسالتك بسبب خطأ تقني',

	// F
	'form_pet_message_commentaire' => 'یک پیام یا تفسیر؟',
	'forum' => 'سخنگاه',
	'forum_acces_refuse' => '.شما ديگر اجازه استفاده از اين سخنگاه را نداريد',
	'forum_attention_dix_caracteres' => '</b>! توجه<b>   پيامتان بايد بيش از ده حرف باشد.',
	'forum_attention_message_non_poste' => 'دقیت کنید، شما هنوز پیامی نفرستاده اید!',
	'forum_attention_nb_caracteres_mini' => '<b>توجه!</b> پيام شكا بايد دست كم بايد @min@ كاراكتر داشته باشد.',
	'forum_attention_trois_caracteres' => '</b>! توجه<b> عنوانتان بايد بيش از سه حرف باشد. ',
	'forum_attention_trop_caracteres' => '<b>توجه!</b>(@compte@ كاراكتر براي آنكه ثبت شود، نبايد از @max@ كاراكتر بيشتر شود. )  پيام شما زياد طولاني است ',
	'forum_avez_selectionne' => ': شما انتخاب كرده ايد',
	'forum_cliquer_retour' => ' </a> اينجا <a href=\'@retour_forum@\'>     را براى ادامه كليك كنيد     ',
	'forum_forum' => 'سخنگاه',
	'forum_info_modere' => 'اين سخنگاه از پيش تعديل مي‌شود: نظر شما پيش از تأييد مديران سايت ظاهر نخواهد شد.',
	'forum_lien_hyper' => ' پيوند هايپرتكست  ',
	'forum_message' => 'پيام شما',
	'forum_message_definitif' => 'پيام نهايى : به سايت بفرستيد',
	'forum_message_trop_long' => 'پيامتان بيش از حد بلند است. حداكثر اندازه ٢٠٠٠٠ حرف است',
	'forum_ne_repondez_pas' => 'به اين ايميل مستقيماً پاسخ ندهيد-از سخنگاه وصل‌خط در نشاني زير استفاده كنيد:',
	'forum_page_url' => 'اگر پيامتان راجع به يك مقاله چاپ شده يا به يك صفحه اى كه داراى اطلاعات سودمندى است مربوط ميشود، خواهشمند است عنوان صفحه وآدرس آنرا در زير مشخص كنيد ',
	'forum_permalink' => 'پيوند دائمي به نظر',
	'forum_poste_par' => 'پيام @parauteur@ بدنبال مقاله « @titre@ »  فرستاده شده. ', # MODIF
	'forum_qui_etes_vous' => ' كى هستيد؟                                      ',
	'forum_saisie_texte_info' => 'اين فرم خلاصه‌هاي اسپيپ را مي‌پذيرد  <code>[->url] {{gras}} {italique} <quote> <code></code>   و كد‌هاي  HTML <code><q> <del> <ins></code>. براي ايجاد پارگراف، يك خط خالي بگذاريد. .',
	'forum_texte' => 'متن پيامتان',
	'forum_titre' => ':تيتر',
	'forum_url' => 'وب سايت شما ',
	'forum_valider' => 'اين انتخاب را معتبر كنيد',
	'forum_voir_avant' => 'پيش‌نمايش',
	'forum_votre_email' => 'آدرس ايميل تان',
	'forum_votre_nom' => 'نام شما',
	'forum_vous_enregistrer' => ' براى شركت در اين سخنگاه، شما بايد از پيش ثبت نام ميكرديد. خواهشمند است كلمه شناساييتان را كه دريافت كرده ايد در زير مشخص كنيد.اگر ثبت نشديد، بايد',
	'forum_vous_inscrire' => 'ثبت نام كنيد.   ',

	// I
	'icone_bruler_message' => 'مانند اسپم به نظر مي‌رسد',
	'icone_bruler_messages' => 'مانند اسپم به نظر مي‌رسد',
	'icone_legitimer_message' => 'مجاز به نظر مي‌رسد',
	'icone_poster_message' => 'يك پيام بفرستيد',
	'icone_suivi_forum' => '                                                                                                  دنباله سخنگاه همگانى : @nb_forums@ پيام                                                       ',
	'icone_suivi_forums' => 'پيگيرى/اداره كردن سخنگاه',
	'icone_supprimer_message' => 'اين پيام را حذف كنيد',
	'icone_supprimer_messages' => 'حذف اين پيام‌ها',
	'icone_valider_message' => 'اين پيام را معتبر كنيد',
	'icone_valider_messages' => 'معبرساختن اين پيام‌ها',
	'icone_valider_repondre_message' => 'معتبر كردن و پاسخ دادن به اين پيام',
	'info_1_message_forum' => '1 پيام از سخنگاه',
	'info_activer_forum_public' => ' براى فعال كردن سخنگاه همگانى، خواهشمند است شيوه تعديل پيش‌گزيده را انتخاب كنيد:',
	'info_appliquer_choix_moderation' => ': اين انتخاب معتدل را بكار بريد',
	'info_config_forums_prive' => 'در قسمت شخصي سايت مي‌توانيد چند نوع سخنگاه را فعال كنيد:',
	'info_config_forums_prive_admin' => 'يك سخنگاه اختصاصي براي مديران سايت:',
	'info_config_forums_prive_global' => 'يك سخنگاه‌ي كلي، گشوده به روي تمام نويسندگان:',
	'info_config_forums_prive_objets' => 'يك سخناگاه براي هر مقاله، خبر و سايت‌ ارجاعي و غيره:',
	'info_desactiver_forum_public' => 'استفاده از سخنگاه همگانى را غير فعال كنيد. استفاده از آن ميتواند مورد به مورد درباره مقالات داده شود، ولى در موارد ديگر ممنوع خواهد بود',
	'info_envoi_forum' => 'ارسال سخنگاه به نويسند گان مقاله ها',
	'info_fonctionnement_forum' => ': عملكرد سخنگاه',
	'info_forums_liees_mot' => 'پيام‌هاي سخنگاه مربوط به اين واژه',
	'info_gauche_suivi_forum_2' => 'صفحه<i> پيگيري سخنگاه‌ها </i> ابزار اداره سايت (و نه مكانى براى بحث يا نگارش) شماست. اين صفحه، امكان اعلان تمام پيامهاى سخنگاه همگانى و خصوصى و همچنين اداره پيامها را بشما ميدهد.',
	'info_liens_syndiques_3' => 'سخنگاه',
	'info_liens_syndiques_4' => 'هستند',
	'info_liens_syndiques_5' => 'سخنگاه',
	'info_liens_syndiques_6' => 'هست',
	'info_liens_syndiques_7' => 'در انتظار تأئيد',
	'info_liens_texte' => 'پيوند‌(هاي) محتوا((ها) در داخل متن پيام',
	'info_liens_titre' => 'پيوند‌(هاي) محتوا(ها) در تيتر پيام',
	'info_mode_fonctionnement_defaut_forum_public' => 'طرز عملكرد سخنگاه هاى عمومى',
	'info_nb_messages_forum' => '@nb@ پيام از سخنگاه',
	'info_option_email' => 'هنگاميكه يكى از بينند گان سايت پيامى در سخنگاه راجع به مقاله‌اى مي‌فرستد، نويسند گان مقاله  مي‌توانند از آن آگاه شوند. آيا مي‌خواهيد اين گزينه را داشته باشيد؟',
	'info_pas_de_forum' => 'بدون سخنگاه',
	'info_question_visiteur_ajout_document_forum' => 'اگر مايليد به بازديد‌كنندگان اجازه دهيد كه سند‌هايي (تصوير، صدا و . . . ) را به پيام‌هايشان در سخنگاه بچسبانند، فهرست توسعه‌هاي مجاز براي سند‌ها را براي سخنگاه‌ها، در زير، مشخص كنيد (ex: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'اگر مايليد به تمام انواع سند‌هايي كه با اسپيپ منطبق است اجازه بدهيد، يك ستاره بگذاريد. اگر اجازه نمي‌دهيد هيچ كار نكنيد.',
	'interface_formulaire' => 'فرم ميانجي',
	'interface_onglets' => 'فرم‌ها با تب‌ها',
	'item_activer_forum_administrateur' => 'سخنگاه گردانندگان سايت را فعال كنيد',
	'item_config_forums_prive_global' => 'فعال سازي سخنگاه نويسندگان',
	'item_config_forums_prive_objets' => 'فعال سازي اين سخنگاه‌ها',
	'item_desactiver_forum_administrateur' => 'سخنگاه گردانندگان سايت را غير فعال كنيد',
	'item_non_config_forums_prive_global' => 'غيرفعال سازي سخنگاه نويسندگان',
	'item_non_config_forums_prive_objets' => 'غيرفعال سازي اين سخنگاه‌ها',

	// L
	'lien_reponse_article' => 'پاسخ به مقاله',
	'lien_reponse_breve_2' => 'پاسخ به مقاله كوتاه',
	'lien_reponse_message' => 'پاسخ به يك پيام',
	'lien_reponse_rubrique' => 'پاسخ به بخش',
	'lien_reponse_site_reference' => ':پاسخ به سايت مرجع',

	// M
	'messages_aucun' => 'هيچ',
	'messages_meme_auteur' => 'تمام پيام‌هاي اين نويسنده',
	'messages_meme_email' => 'تمام پيام‌هاي اين ايميل',
	'messages_meme_ip' => 'تمام پيام‌هاي اين آي.پي',
	'messages_off' => 'حذفي‌ها',
	'messages_perso' => 'اشخاص',
	'messages_privadm' => 'ادمين‌ها',
	'messages_prive' => 'خصوصي',
	'messages_privoff' => 'حذفي‌ها',
	'messages_privrac' => 'همگاني‌ها',
	'messages_prop' => 'پيشنهادي‌ها',
	'messages_publie' => 'منتشرشده‌ها',
	'messages_spam' => 'اسپم',
	'messages_tous' => 'همه',

	// O
	'onglet_messages_internes' => 'پيام هاى داخلى',
	'onglet_messages_publics' => 'پيام هاى همگانى',
	'onglet_messages_vide' => 'پيام هاى بدون متن',

	// R
	'repondre_message' => 'پاسخ به اين پيام',

	// S
	'statut_off' => 'حذفي',
	'statut_original' => 'اصلی',
	'statut_prop' => 'پيشنهادي',
	'statut_publie' => 'منتشر شده',
	'statut_spam' => 'اسپم',

	// T
	'text_article_propose_publication_forum' => 'از طريق سخنگاه پيوست در پائين همين صفحه نظرتان را مورد اين مقاله بيان كنيد.',
	'texte_en_cours_validation' => 'مطالب زير منتظر تأييد‌اند',
	'texte_en_cours_validation_forum' => 'مي‌توانيد از طريق سخنگاه‌هاي پيوست شده به‌ آن‌ها نظراتتان را بيان كنيد.',
	'texte_messages_publics' => 'پيام‌هاي همگاني در مورد:‌',
	'titre_cadre_forum_administrateur' => 'سخنگاه خصوصى گردانندگان سايت',
	'titre_cadre_forum_interne' => 'سخنگاه داخلى',
	'titre_config_forums_prive' => 'سخنگاه‌هاي قسمت شخصي',
	'titre_forum' => 'سخنگاه',
	'titre_forum_suivi' => 'دنباله سخنگاه ',
	'titre_page_forum_suivi' => 'دنباله سخنگاه',
	'titre_selection_action' => 'گزينش',
	'tout_voir' => 'تمام پيام‌ها را بنگريد',

	// V
	'voir_messages_objet' => 'تمام پيام‌ها را بنگريد'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'لا يوجد اي رسائل منتدى',

	// B
	'bouton_radio_articles_futurs' => ' ( منحصرأ براى مقالات آينده (بر روى  داده پى ها بى تأثير ميباشد',
	'bouton_radio_articles_tous' => 'به تمامى مقاله ها، بدون استثناء',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'به تمامى مقاله ها، بجز آنهائى كه سخنگاهشان غير فعال است. ',
	'bouton_radio_enregistrement_obligatoire' => 'ضبط اجبارى، (كاربران بايد, براى داشتن آدرس الكترونيكى  مشترك شوند تا بتوانند پيامهايشان را پست كنند)      ',
	'bouton_radio_moderation_priori' => 'تعديل از پيش (نوشته‌ها پيش از تأييد مديران منتشر نمي‌شوند).',
	'bouton_radio_modere_abonnement' => 'براى مشتركين',
	'bouton_radio_modere_posteriori' => 'تعديل بعدي ',
	'bouton_radio_modere_priori' => 'تعديل از پيش',
	'bouton_radio_publication_immediate' => 'انتشار فورى پيامها 
 (پيامها بمحض فرستاده شدن نمايان ميشوند سپس گردانند گان سايت ميتوانند آنها را حذف كنند)',

	// D
	'documents_interdits_forum' => 'سندهاي ممنوع در سخناگاه ',

	// E
	'erreur_enregistrement_message' => 'لم يتم تسجيل رسالتك بسبب خطأ تقني',

	// F
	'form_pet_message_commentaire' => 'یک پیام یا تفسیر؟',
	'forum' => 'سخنگاه',
	'forum_acces_refuse' => '.شما ديگر اجازه استفاده از اين سخنگاه را نداريد',
	'forum_attention_dix_caracteres' => '</b>! توجه<b>   پيامتان بايد بيش از ده حرف باشد.',
	'forum_attention_message_non_poste' => 'دقیت کنید، شما هنوز پیامی نفرستاده اید!',
	'forum_attention_nb_caracteres_mini' => '<b>توجه!</b> پيام شكا بايد دست كم بايد @min@ كاراكتر داشته باشد.',
	'forum_attention_trois_caracteres' => '</b>! توجه<b> عنوانتان بايد بيش از سه حرف باشد. ',
	'forum_attention_trop_caracteres' => '<b>توجه!</b>(@compte@ كاراكتر براي آنكه ثبت شود، نبايد از @max@ كاراكتر بيشتر شود. )  پيام شما زياد طولاني است ',
	'forum_avez_selectionne' => ': شما انتخاب كرده ايد',
	'forum_cliquer_retour' => ' </a> اينجا <a href=\'@retour_forum@\'>     را براى ادامه كليك كنيد     ',
	'forum_forum' => 'سخنگاه',
	'forum_info_modere' => 'اين سخنگاه از پيش تعديل مي‌شود: نظر شما پيش از تأييد مديران سايت ظاهر نخواهد شد.',
	'forum_lien_hyper' => ' پيوند هايپرتكست  ',
	'forum_message' => 'پيام شما',
	'forum_message_definitif' => 'پيام نهايى : به سايت بفرستيد',
	'forum_message_trop_long' => 'پيامتان بيش از حد بلند است. حداكثر اندازه ٢٠٠٠٠ حرف است',
	'forum_ne_repondez_pas' => 'به اين ايميل مستقيماً پاسخ ندهيد-از سخنگاه وصل‌خط در نشاني زير استفاده كنيد:',
	'forum_page_url' => 'اگر پيامتان راجع به يك مقاله چاپ شده يا به يك صفحه اى كه داراى اطلاعات سودمندى است مربوط ميشود، خواهشمند است عنوان صفحه وآدرس آنرا در زير مشخص كنيد ',
	'forum_permalink' => 'پيوند دائمي به نظر',
	'forum_poste_par' => 'پيام @parauteur@ بدنبال مقاله « @titre@ »  فرستاده شده. ', # MODIF
	'forum_qui_etes_vous' => ' كى هستيد؟                                      ',
	'forum_saisie_texte_info' => 'اين فرم خلاصه‌هاي اسپيپ را مي‌پذيرد  <code>[->url] {{gras}} {italique} <quote> <code></code>   و كد‌هاي  HTML <code><q> <del> <ins></code>. براي ايجاد پارگراف، يك خط خالي بگذاريد. .',
	'forum_texte' => 'متن پيامتان',
	'forum_titre' => ':تيتر',
	'forum_url' => 'وب سايت شما ',
	'forum_valider' => 'اين انتخاب را معتبر كنيد',
	'forum_voir_avant' => 'پيش‌نمايش',
	'forum_votre_email' => 'آدرس ايميل تان',
	'forum_votre_nom' => 'نام شما',
	'forum_vous_enregistrer' => ' براى شركت در اين سخنگاه، شما بايد از پيش ثبت نام ميكرديد. خواهشمند است كلمه شناساييتان را كه دريافت كرده ايد در زير مشخص كنيد.اگر ثبت نشديد، بايد',
	'forum_vous_inscrire' => 'ثبت نام كنيد.   ',

	// I
	'icone_bruler_message' => 'مانند اسپم به نظر مي‌رسد',
	'icone_bruler_messages' => 'مانند اسپم به نظر مي‌رسد',
	'icone_legitimer_message' => 'مجاز به نظر مي‌رسد',
	'icone_poster_message' => 'يك پيام بفرستيد',
	'icone_suivi_forum' => '                                                                                                  دنباله سخنگاه همگانى : @nb_forums@ پيام                                                       ',
	'icone_suivi_forums' => 'پيگيرى/اداره كردن سخنگاه',
	'icone_supprimer_message' => 'اين پيام را حذف كنيد',
	'icone_supprimer_messages' => 'حذف اين پيام‌ها',
	'icone_valider_message' => 'اين پيام را معتبر كنيد',
	'icone_valider_messages' => 'معبرساختن اين پيام‌ها',
	'icone_valider_repondre_message' => 'معتبر كردن و پاسخ دادن به اين پيام',
	'info_1_message_forum' => '1 پيام از سخنگاه',
	'info_activer_forum_public' => ' براى فعال كردن سخنگاه همگانى، خواهشمند است شيوه تعديل پيش‌گزيده را انتخاب كنيد:',
	'info_appliquer_choix_moderation' => ': اين انتخاب معتدل را بكار بريد',
	'info_config_forums_prive' => 'در قسمت شخصي سايت مي‌توانيد چند نوع سخنگاه را فعال كنيد:',
	'info_config_forums_prive_admin' => 'يك سخنگاه اختصاصي براي مديران سايت:',
	'info_config_forums_prive_global' => 'يك سخنگاه‌ي كلي، گشوده به روي تمام نويسندگان:',
	'info_config_forums_prive_objets' => 'يك سخناگاه براي هر مقاله، خبر و سايت‌ ارجاعي و غيره:',
	'info_desactiver_forum_public' => 'استفاده از سخنگاه همگانى را غير فعال كنيد. استفاده از آن ميتواند مورد به مورد درباره مقالات داده شود، ولى در موارد ديگر ممنوع خواهد بود',
	'info_envoi_forum' => 'ارسال سخنگاه به نويسند گان مقاله ها',
	'info_fonctionnement_forum' => ': عملكرد سخنگاه',
	'info_forums_liees_mot' => 'پيام‌هاي سخنگاه مربوط به اين واژه',
	'info_gauche_suivi_forum_2' => 'صفحه<i> پيگيري سخنگاه‌ها </i> ابزار اداره سايت (و نه مكانى براى بحث يا نگارش) شماست. اين صفحه، امكان اعلان تمام پيامهاى سخنگاه همگانى و خصوصى و همچنين اداره پيامها را بشما ميدهد.',
	'info_liens_syndiques_3' => 'سخنگاه',
	'info_liens_syndiques_4' => 'هستند',
	'info_liens_syndiques_5' => 'سخنگاه',
	'info_liens_syndiques_6' => 'هست',
	'info_liens_syndiques_7' => 'در انتظار تأئيد',
	'info_liens_texte' => 'پيوند‌(هاي) محتوا((ها) در داخل متن پيام',
	'info_liens_titre' => 'پيوند‌(هاي) محتوا(ها) در تيتر پيام',
	'info_mode_fonctionnement_defaut_forum_public' => 'طرز عملكرد سخنگاه هاى عمومى',
	'info_nb_messages_forum' => '@nb@ پيام از سخنگاه',
	'info_option_email' => 'هنگاميكه يكى از بينند گان سايت پيامى در سخنگاه راجع به مقاله‌اى مي‌فرستد، نويسند گان مقاله  مي‌توانند از آن آگاه شوند. آيا مي‌خواهيد اين گزينه را داشته باشيد؟',
	'info_pas_de_forum' => 'بدون سخنگاه',
	'info_question_visiteur_ajout_document_forum' => 'اگر مايليد به بازديد‌كنندگان اجازه دهيد كه سند‌هايي (تصوير، صدا و . . . ) را به پيام‌هايشان در سخنگاه بچسبانند، فهرست توسعه‌هاي مجاز براي سند‌ها را براي سخنگاه‌ها، در زير، مشخص كنيد (ex: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'اگر مايليد به تمام انواع سند‌هايي كه با اسپيپ منطبق است اجازه بدهيد، يك ستاره بگذاريد. اگر اجازه نمي‌دهيد هيچ كار نكنيد.',
	'interface_formulaire' => 'فرم ميانجي',
	'interface_onglets' => 'فرم‌ها با تب‌ها',
	'item_activer_forum_administrateur' => 'سخنگاه گردانندگان سايت را فعال كنيد',
	'item_config_forums_prive_global' => 'فعال سازي سخنگاه نويسندگان',
	'item_config_forums_prive_objets' => 'فعال سازي اين سخنگاه‌ها',
	'item_desactiver_forum_administrateur' => 'سخنگاه گردانندگان سايت را غير فعال كنيد',
	'item_non_config_forums_prive_global' => 'غيرفعال سازي سخنگاه نويسندگان',
	'item_non_config_forums_prive_objets' => 'غيرفعال سازي اين سخنگاه‌ها',

	// L
	'lien_reponse_article' => 'پاسخ به مقاله',
	'lien_reponse_breve_2' => 'پاسخ به مقاله كوتاه',
	'lien_reponse_message' => 'پاسخ به يك پيام',
	'lien_reponse_rubrique' => 'پاسخ به بخش',
	'lien_reponse_site_reference' => ':پاسخ به سايت مرجع',

	// M
	'messages_aucun' => 'هيچ',
	'messages_meme_auteur' => 'تمام پيام‌هاي اين نويسنده',
	'messages_meme_email' => 'تمام پيام‌هاي اين ايميل',
	'messages_meme_ip' => 'تمام پيام‌هاي اين آي.پي',
	'messages_off' => 'حذفي‌ها',
	'messages_perso' => 'اشخاص',
	'messages_privadm' => 'ادمين‌ها',
	'messages_prive' => 'خصوصي',
	'messages_privoff' => 'حذفي‌ها',
	'messages_privrac' => 'همگاني‌ها',
	'messages_prop' => 'پيشنهادي‌ها',
	'messages_publie' => 'منتشرشده‌ها',
	'messages_spam' => 'اسپم',
	'messages_tous' => 'همه',

	// O
	'onglet_messages_internes' => 'پيام هاى داخلى',
	'onglet_messages_publics' => 'پيام هاى همگانى',
	'onglet_messages_vide' => 'پيام هاى بدون متن',

	// R
	'repondre_message' => 'پاسخ به اين پيام',

	// S
	'statut_off' => 'حذفي',
	'statut_original' => 'اصلی',
	'statut_prop' => 'پيشنهادي',
	'statut_publie' => 'منتشر شده',
	'statut_spam' => 'اسپم',

	// T
	'text_article_propose_publication_forum' => 'از طريق سخنگاه پيوست در پائين همين صفحه نظرتان را مورد اين مقاله بيان كنيد.',
	'texte_en_cours_validation' => 'مطالب زير منتظر تأييد‌اند',
	'texte_en_cours_validation_forum' => 'مي‌توانيد از طريق سخنگاه‌هاي پيوست شده به‌ آن‌ها نظراتتان را بيان كنيد.',
	'texte_messages_publics' => 'پيام‌هاي همگاني در مورد:‌',
	'titre_cadre_forum_administrateur' => 'سخنگاه خصوصى گردانندگان سايت',
	'titre_cadre_forum_interne' => 'سخنگاه داخلى',
	'titre_config_forums_prive' => 'سخنگاه‌هاي قسمت شخصي',
	'titre_forum' => 'سخنگاه',
	'titre_forum_suivi' => 'دنباله سخنگاه ',
	'titre_page_forum_suivi' => 'دنباله سخنگاه',
	'titre_selection_action' => 'گزينش',
	'tout_voir' => 'تمام پيام‌ها را بنگريد',

	// V
	'voir_messages_objet' => 'تمام پيام‌ها را بنگريد',
];
